@@ -167,6 +167,14 @@ peer_free(GS_SELECT_CTX *ctx, struct _peer *p)
 	DEBUGF_Y("free'ing peer on fd = %d\n", fd);
 	memset(p, 0, sizeof *p);
 	XFREE(peers[fd]);
+	// FIXME: Eventually GS_shutdown() needs to return ECALLAGAIN and then do 2 things:
+	// 1. Monitor socket for reading. Timeout after 10 seconds (peer died).
+	// 2. Poll on TIOCOUTQ and once empty call close().
+	// https://blog.netherlabs.nl/articles/2009/01/18/the-ultimate-so_linger-page-or-why-is-my-tcp-not-reliable
+	if (is_stdin_forward)
+	{
+		fd_kernel_flush(gs->fd);
+	}
 	GS_close(gs);	// sets gs->fd to -1
 	gopt.peer_count = MAX(gopt.peer_count - 1, 0);
 	DEBUGF_M("Freed gs-peer. Still connected: %d\n", gopt.peer_count);
@@ -183,7 +191,10 @@ peer_free(GS_SELECT_CTX *ctx, struct _peer *p)
 
 	/* STDIN/STDOUT reading supports one gs connection only */
 	if (is_stdin_forward)
+	{
+		DEBUGF("exiting...\n");
 		exit(0);
+	}
 }
 
 static void
@@ -361,7 +372,6 @@ cb_read_fd(GS_SELECT_CTX *ctx, int fd, void *arg, int val)
 		{
 			// UDP packaging over TCP = [ 16 bit length | payload ]
 			p->wlen = read(fd, p->wbuf + 2, p->w_max - 2);
-			DEBUGF("read=%zd\n", p->wlen);
 			if (p->wlen > 0)
 			{
 				uint16_t len = htons(p->wlen);
@@ -370,6 +380,7 @@ cb_read_fd(GS_SELECT_CTX *ctx, int fd, void *arg, int val)
 			}
 		} else {
 			p->wlen = read(fd, p->wbuf, p->w_max);
+			DEBUGF("read=%zd\n", p->wlen);
 		}
 
 		if (p->wlen == 0)
@@ -1053,8 +1064,14 @@ cb_listen(GS_SELECT_CTX *ctx, int fd, void *arg, int val)
 	gs_new = GS_accept(gs, &err);
 	if (gs_new == NULL)
 	{
+
 		if (err <= -2)
-			ERREXIT("%s\n", GS_CTX_strerror(gs->ctx)); //Another Server is already listening or Network error.\n");
+		{
+			int code = 255;
+			if (gs->status_code == GS_STATUS_CODE_BAD_AUTH)
+				code = EX_BAD_AUTH;
+			ERREXITC(code, "%s\n", GS_CTX_strerror(gs->ctx)); //Another Server is already listening or Network error.\n");
+		}
 		/* HERE: GS_accept() is not ready yet to accept() a new
 		 * gsocket. (May have processed GS-pkt data) or may have 
 		 * closed the socket and established a new one (to wait for
@@ -1135,6 +1152,12 @@ cb_connect_client(GS_SELECT_CTX *ctx, int fd_notused, void *arg, int val)
 		{
 			if (gs->status_code == GS_STATUS_CODE_CONNREFUSED)
 				exit(EX_CONNREFUSED); // Used by deploy.sh to verify that server is responding.
+			// Used in deploy.sh to check if server is listening with
+			// _GSOCKET_SERVER_CHECK_SEC=10 gs-netcat -s foobar
+			if ((gopt.gs_server_check_sec > 0) && (gs->status_code == GS_STATUS_CODE_SERVER_OK))
+				exit(0);
+			if (gs->status_code == GS_STATUS_CODE_NETERROR)
+				exit(EX_NETERROR);
 			exit(EX_FATAL);
 		}
 		/* This can happen if server accepts 1 connection only but client
@@ -1153,6 +1176,7 @@ cb_connect_client(GS_SELECT_CTX *ctx, int fd_notused, void *arg, int val)
 		return GS_ECALLAGAIN;
 
 	DEBUGF_M("*** GS_connect() SUCCESS ***** %d %d %d\n", gs->fd, p->fd_in, p->fd_out);
+
 	/* HERE: Connection successfully established */
 	/* Start reading from Network (SRP is handled by GS_read()/GS_write()) */
 	GS_SELECT_add_cb(ctx, cb_read_gs, cb_write_gs, gs->fd, p, 0);
@@ -1355,11 +1379,18 @@ my_usage(void)
 	exit(EX_UNKNWNCMD);
 }
 
+static void
+cb_sigalarm(int sig)
+{
+	exit(EX_ALARM);
+}
+
 static void
 my_getopt(int argc, char *argv[])
 {
 	int c;
 	FILE *fp;
+	char *ptr;
 
 	do_getopt(argc, argv);	/* from utils.c */
 	optind = 1;	/* Start from beginning */
@@ -1423,6 +1454,15 @@ my_getopt(int argc, char *argv[])
 		gopt.is_internal = 1;
 	}
 
+	ptr = getenv("_GSOCKET_SERVER_CHECK_SEC");
+	if (ptr != NULL)
+	{
+		DEBUGF_G("SERVER_CHECK_SEC=%s (%d)\n", ptr, atoi(ptr));
+		gopt.gs_server_check_sec = atoi(ptr);
+		alarm(gopt.gs_server_check_sec);
+		signal(SIGALRM, cb_sigalarm);
+	}
+
 	if (gopt.is_daemon)
 	{
 		if (gopt.is_logfile == 0)
@@ -1480,13 +1520,25 @@ my_getopt(int argc, char *argv[])
 	init_vars();			/* from utils.c */
 
 	/* Become a daemon & watchdog (auto-restart)
-	 * Do this before gs_create() so that any error in resolving
+	 * Do this before gs_create() so that any error in DNS resolving
 	 * is re-tried by watchdog.
 	 */
 	if (gopt.is_daemon)
 	{
+		if (gopt.token_str == NULL)
+		{
+			// Stop multiple daemons from starting (by crontab/.profile):
+			// Set the token-str uniq to this daemon. Then any other daemon
+			// that starts will have a different toek_str and GSRN will return
+			// a BAD-AUTH message.
+			// The child will then exit with  EX_BAD_AUTH which also triggers the daemon
+			// to exit (because another daemon is already connected).
+			char buf[1024];
+			snprintf(buf, sizeof buf, "%u-BAD-AUTH-CHECK-%s", getpid(), gopt.sec_str);
+			gopt.token_str = strdup(buf);
+		}
 		gopt.err_fp = gopt.log_fp;	// Errors to logfile or NULL
-		GS_daemonize(gopt.log_fp);
+		GS_daemonize(gopt.log_fp, EX_BAD_AUTH);
 	}
 
 	gopt.gsocket = gs_create();
