@@ -197,6 +197,8 @@ init_vars(void)
 	if (gopt.is_interactive != 0)
 		GS_CTX_setsockopt(&gopt.gs_ctx, GS_OPT_LOW_LATENCY, NULL, 0);
 
+	if (gopt.gs_server_check_sec > 0)
+		GS_CTX_setsockopt(&gopt.gs_ctx, GS_OPT_SERVER_CHECK, NULL, 0);
 
 	// Prevent startup messages if gs-netcat is started as sub-system from
 	// gs-sftp or gs-mount
@@ -932,6 +934,31 @@ fd_new_socket(int type)
 	return fd;
 }
 
+void
+fd_kernel_flush(int fd)
+{
+#ifdef TIOCOUTQ
+	int value = 0;
+	int i;
+	int ret;
+
+	for (i = 0; i < 10; i++)
+	{
+		if (ioctl(fd, TIOCOUTQ, &value) != 0)
+			break;
+		if (value == 0)
+			break;
+
+		socklen_t len = sizeof (value);
+		ret = getsockopt(fd, SOL_SOCKET, SO_ERROR, &value, &len);
+		if ((ret != 0) || (value == EPIPE))
+			break;
+
+		usleep(10 * 1000);
+	}
+#endif
+}
+
 void
 cmd_ping(struct _peer *p)
 {
